CSGraphAnchorSearcher
=====================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: CSGraphAnchorSearcher
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CSGraphAnchorSearcher.__call__
      ~CSGraphAnchorSearcher.topk_argpartition
      ~CSGraphAnchorSearcher.topk_argsort

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: topk_argpartition
   .. automethod:: topk_argsort
